@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 #include "mutt.h"
@@ -139,6 +139,17 @@ ADDRESS *mutt_expand_aliases (ADDRESS *a)
   return (t);
 }
 
+void mutt_expand_aliases_env (ENVELOPE *env)
+{
+  env->from = mutt_expand_aliases (env->from);
+  env->to = mutt_expand_aliases (env->to);
+  env->cc = mutt_expand_aliases (env->cc);
+  env->bcc = mutt_expand_aliases (env->bcc);
+  env->reply_to = mutt_expand_aliases (env->reply_to);
+  env->mail_followup_to = mutt_expand_aliases (env->mail_followup_to);
+}
+
+
 /* 
  * if someone has an address like
  *	From: Michael `/bin/rm -f ~` Elkins <me@cs.hmc.edu>
