@@ -56,6 +56,8 @@ int imap_read_headers (CONTEXT *ctx, int msgbegin, int msgend)
   IMAP_HEADER *h, *h0;
   const char *want_headers = "DATE FROM SUBJECT TO CC MESSAGE-ID REFERENCES CONTENT-TYPE IN-REPLY-TO REPLY-TO LINES";
   int using_body_peek = 0;
+  int c;
+  
   fetchlast = 0;
 
   /* define search string */
@@ -233,7 +235,6 @@ int imap_read_headers (CONTEXT *ctx, int msgbegin, int msgend)
     ctx->hdrs[ctx->msgcount] = mutt_new_header ();
     ctx->hdrs[ctx->msgcount]->index = ctx->msgcount;
 
-    ctx->hdrs[msgno]->env = mutt_read_rfc822_header (fp, ctx->hdrs[msgno], 0, 0);
     ploc = ftell (fp);
     ctx->hdrs[msgno]->read = h->read;
     ctx->hdrs[msgno]->old = h->old;
@@ -242,15 +243,29 @@ int imap_read_headers (CONTEXT *ctx, int msgbegin, int msgend)
     ctx->hdrs[msgno]->replied = h->replied;
     ctx->hdrs[msgno]->changed = h->changed;
     ctx->hdrs[msgno]->received = h->received;
-    ctx->hdrs[msgno]->content->length = h->content_length;
     ctx->hdrs[msgno]->data = (void *) (h->data);
 
+    /* NOTE: if Date: header is missing, mutt_read_rfc822_header depends
+     *   on h->received being set */
+    ctx->hdrs[msgno]->env = mutt_read_rfc822_header (fp, ctx->hdrs[msgno], 0, 0);
+    /* content built as a side-effect of mutt_read_rfc822_header */
+    ctx->hdrs[msgno]->content->length = h->content_length;
+
     mx_update_context (ctx); /* increments ->msgcount */
 
     h0 = h;
     h = h->next;
     /* hdata is freed later */
     safe_free ((void **) &h0);
+
+    /* 
+     * skip over additional \n characters - Courier IMAP seems to
+     * put them here.
+     */
+    
+    while ((c = fgetc (fp)) == '\n')
+      ;
+    ungetc (c, fp);
   }
   
   fclose(fp);
