@@ -301,6 +301,9 @@ enum
   OPTIMAPLSUB,
   OPTIMAPPASSIVE,
   OPTIMAPSERVERNOISE,
+# ifdef USE_SSL
+  OPTIMAPFORCESSL,
+# endif
 #endif
 #ifdef USE_SSL
   OPTSSLV2,
